pub struct GitInfo {
pub hash: String,
pub author_name: String,
pub pr_number: Option<u64>,
pub pr_author_login: Option<String>,
}Expand description
Git commit information including hash and author, optionally enriched with forge data.
Fields
hash: Stringpr_number: Option<u64>The PR/MR number that introduced this commit, if fetched from a forge.
The forge login/username of the author of the PR which introduced this commit, if fetched from a forge.