pub struct Changelog {
pub path: RelativePathBuf,
pub content: String,
/* private fields */
}Fields
path: RelativePathBufThe path to the CHANGELOG file
content: StringThe content that’s been written to path
Implementations
Sourceimpl Changelog
impl Changelog
pub fn new(path: RelativePathBuf, content: String) -> Self
Sourcepub fn get_release(
&self,
version: &Version,
package_name: &Name,
) -> Option<Release>
pub fn get_release( &self, version: &Version, package_name: &Name, ) -> Option<Release>
Find a release matching version, if any, within the changelog.
Sourcepub fn with_release(&mut self, release: &Release) -> String
pub fn with_release(&mut self, release: &Release) -> String
Update self.content with the new release, return the diff being applied.