Structs
- Error
- Label
- The label component of a Prerelease (e.g., “alpha” in “1.0.0-alpha.1”).
- Package
Versions - It’s not enough to just track one version for each package, we need:
- PreRelease
NotFound - PreVersion
- Prerelease
- Stable
Version
Enums
- Rule
- The various rules that can be used when bumping semantic versions.
- Stable
Rule - The rules that only apply to stable versions (no pre-releases)
- Version