Struct knope_versioning::semver::PackageVersions
source · pub struct PackageVersions { /* private fields */ }Expand description
It’s not enough to just track one version for each package, we need:
- The latest stable version (if any)
- The last version of each type of pre-release following the latest stable version
So we might have 1.2.3, 1.2.4-rc.1, 1.3.0-beta.0, and 2.0.0-alpha.4
Implementations
sourceimpl PackageVersions
impl PackageVersions
Get the (relevant) current versions from a slice of Git tags.
Tags are expected to either be v{version} or {prefix}/v{version} (if supplied),
Parameters
prefix: Only tag names starting with this string will be considered.all_tags: All tags in the repository.
sourcepub fn into_latest(self) -> Version
pub fn into_latest(self) -> Version
Consumes self to produce the most recent version (determined by order of tags).
sourcepub fn update_version(&mut self, version: Version)
pub fn update_version(&mut self, version: Version)
Replace or insert the version in the correct location if it’s newer than the current
equivalent version.
If the version is a newer stable version, it will update stable
and erase all pre-releases.
If the version is a newer prerelease, it will overwrite the prerelease with
the same stable component and label.
sourcepub fn bump(&mut self, rule: Rule) -> Result<(), PreReleaseNotFound>
pub fn bump(&mut self, rule: Rule) -> Result<(), PreReleaseNotFound>
Apply a Rule to a [PackageVersion], incrementing & resetting the correct components.
Versions 0.x
Versions with major component 0 have special meaning in Semantic Versioning and therefore have different behavior:
Rule::Majorwill bump the minor component.Rule::Minorwill bump the patch component.
Errors
Can fail if trying to run Rule::Release when there is no pre-release.
pub fn stable(&self) -> StableVersion