Struct knope_versioning::package::Package

source ·
pub struct Package {
    pub name: Name,
    pub versions: PackageVersions,
    pub release_notes: ReleaseNotes,
    pub scopes: Option<Vec<String>>,
    /* private fields */
}

Fields

name: Nameversions: PackageVersionsrelease_notes: ReleaseNotesscopes: Option<Vec<String>>

Implementations

source

impl Package

source

pub fn new<S: AsRef<str> + Debug>( name: Name, git_tags: &[S], versioned_files: Vec<VersionedFile>, release_notes: ReleaseNotes, scopes: Option<Vec<String>>, ) -> Result<Self, NewError>

Try and combine a bunch of versioned files into one logical package.

Errors

There must be at least one versioned file, and all files must have the same version.

source

pub fn bump_version( &mut self, bump: Bump, go_versioning: GoVersioning, ) -> Result<Vec<Action>, BumpError>

Returns the actions that must be taken to set this package to the new version, along with the version it was set to.

The version can either be calculated from a semver rule or specified manually.

Errors

If the file is a go.mod, there are rules about what versions are allowed.

If serialization of some sort fails, which is a bug, then this will return an error.

If the Rule::Release is specified, but there is no current prerelease, that’s an error too.

source

pub fn get_changes( &self, changeset: &[Release], commit_messages: &[String], ) -> Vec<Change>

source

pub fn apply_changes( &mut self, changes: &[Change], config: ChangeConfig, ) -> Result<Vec<Action>, BumpError>

Apply changes to the package, updating the internal version and returning the list of actions to take to complete the changes.

Errors

If the file is a go.mod, there are rules about what versions are allowed.

If serialization of some sort fails, which is a bug, then this will return an error.