Structs
- Change
Template - Changelog
- Commit
Footer - Custom
Change Type - A non-standard conventional commit type (e.g., the “doc” in “doc: some message”)
or a non-standard changeset type (
changesets::ChangeType::Custom). - Release
- Release
Notes - Defines how release notes are handled for a package.
- Section
Name - Sections
- Time
Error
Enums
- Section
Source - Where a custom release section comes from, for example, the custom change type “extra” in a change file might correspond to a section called “Extras” in the changelog.