Module knope_versioning::release_notes

source ·

Structs

Enums

  • Where a custom release section comes from, for example, the custom change type “extra” in a change file might correspond to a section called “Extras” in the changelog.