Module knope_versioning::release_notes
source · Structs
- A non-standard conventional commit type (e.g., the “doc” in “doc: some message”) or a non-standard changeset type (
changesets::ChangeType::Custom). - Defines how release notes are handled for a package.
Enums
- Where a custom release section comes from, for example, the custom change type “extra” in a change file might correspond to a section called “Extras” in the changelog.